#include <iostream>
#include <fstream>
#include <string>
#include <filesystem>
#include <iomanip>

#include <batteryinfo.h>

void printBattery(std::filesystem::path classPath)
{
	dlore::BatteryInfo bat = dlore::GetBatteryInfo(classPath);

	std::cout << std::fixed << std::setprecision(2);

	std::cout << "Battery " << bat.Manufacturer << bat.Model; // manufacturer has a trailing whitespace, so no additional space necessary
	std::cout << std::endl << "\tTechnology:           " << bat.Technology;
	std::cout << std::endl << "\tCell series count:    " << bat.CellSeriesCount << 's' << std::endl;
	std::cout << std::endl << "\tCapacity:             " << bat.Capacity << '%';
	std::cout << std::endl << "\tCapacity (design):    " << bat.CapacityDesign << '%';
	std::cout << std::endl << "\tVmin:                 " << bat.Vmin << 'V';
	std::cout << "  Per cell: " << bat.Vmin / bat.CellSeriesCount << 'V';
	std::cout << std::endl << "\tVnow:                 " << bat.Vnow << 'V';
	std::cout << "  Per cell: " << bat.Vnow / bat.CellSeriesCount << 'V';
	std::cout << std::endl << "\tCharge now:           " << bat.ChargeNow << "mAh";
	std::cout << std::endl << "\tCharge full:          " << bat.ChargeFull << "mAh (" << bat.ChargeFullPercentageDesign << "% of design)";
	std::cout << std::endl << "\tCharge full (design): " << bat.ChargeFullDesign << "mAh" << std::endl;
}

int main(int argc, const char** argv)
{
	for(const std::filesystem::directory_entry& entry : std::filesystem::directory_iterator("/sys/class/power_supply"))
	{
		std::filesystem::path path = entry.path();
		if(path.filename().string().find("BAT") == std::string::npos) continue; // filename does not contain BAT, continue
		printBattery(path);
	}
	return 0;
}
